@@ -1,7 +1,4 @@
-
-
-class StackStatus():
-
+class StackStatus:
     @classmethod
     def success(cls, status):
         return status in ["CREATE_COMPLETE", "UPDATE_COMPLETE", "DELETE_COMPLETE"]
@@ -13,4 +10,4 @@ class StackStatus():
             "CREATE_FAILED",
             "ROLLBACK_COMPLETE",
             "UPDATE_ROLLBACK_COMPLETE",
-        ]
\ No newline at end of file
+        ]
