@@ -1,10 +1,11 @@
+import json
+
 import click
-from random import randint
-from cli.modules.utils import read_json
+
 from cli.modules.utils import file_exists
 from cli.modules.utils import list_files
-import json
-import os.path
+from cli.modules.utils import read_json
+
 
 @click.group()
 @click.pass_obj
@@ -12,12 +13,13 @@ def show(ctx):
     """show Freeldep variables"""
     pass
 
+
 @show.command()
 @click.argument("name")
 @click.pass_context
 def config(ctx, name):
     """Display resources used by a deployer"""
-    home_folder = ctx.obj.config.get("cli", "home_folder", '~/.freeldep')
+    home_folder = ctx.obj.config.get("cli", "home_folder", "~/.freeldep")
     config_file = home_folder + "/" + name + ".json"
     if file_exists(config_file):
         config = read_json(config_file)
@@ -25,11 +27,11 @@ def config(ctx, name):
     else:
         raise click.BadParameter(f"This deployer {name} does not exist")
 
+
 @show.command()
 @click.pass_context
 def configs(ctx):
     """List all deployers already initialized"""
-    home_folder = ctx.obj.config.get("cli", "home_folder", '~/.freeldep')
+    home_folder = ctx.obj.config.get("cli", "home_folder", "~/.freeldep")
     config_files = list_files(home_folder)
     click.echo("\n".join([x.split(".")[0] for x in config_files]))
-    
\ No newline at end of file
